@@ -2,6 +2,7 @@ from sanic.request import Request
 from sanic.exceptions import SanicException
 from jsonclasses.exceptions import ObjectNotFoundException, ValidationException
 from sanic.response import json
+from traceback import extract_tb
 
 class UnsupportedMediaTypeException(Exception):
 
@@ -24,6 +25,7 @@ def exception_handler(request: Request, exception: Exception):
   return json({
     'error': {
       'type': exception.__class__.__name__,
-      'message': exception.message if hasattr(exception, 'message') else str(exception)
+      'message': exception.message if hasattr(exception, 'message') else str(exception),
+      'traceback': [ f'file {f.filename} line {f.lineno} in {f.name}' for f in extract_tb(exception.__traceback__) ]
     }
   }, status=code)
